@@ -1,6 +1,7 @@
 from typing import List
 
 import click
+
 from robotcode.plugin import hookimpl
 
 from .cli import debug
@@ -8,5 +9,5 @@ from .launcher.cli import debug_launch
 
 
 @hookimpl
-def hatch_register_cli_commands() -> List[click.Command]:
+def register_cli_commands() -> List[click.Command]:
     return [debug, debug_launch]
